/*
 * Copyright 2016-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.gluedatabrew.model;

import java.io.Serializable;
import javax.annotation.Generated;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * 
 * @see <a href="http://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/ListJobs" target="_top">AWS API
 *      Documentation</a>
 */
@Generated("com.amazonaws:aws-java-sdk-code-generator")
public class ListJobsRequest extends com.amazonaws.AmazonWebServiceRequest implements Serializable, Cloneable {

    /**
     * <p>
     * The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     * dataset.
     * </p>
     */
    private String datasetName;
    /**
     * <p>
     * The maximum number of results to return in this request.
     * </p>
     */
    private Integer maxResults;
    /**
     * <p>
     * A token generated by DataBrew that specifies where to continue pagination if a previous request was truncated. To
     * get the next set of pages, pass in the NextToken value from the response object of the previous page call.
     * </p>
     */
    private String nextToken;
    /**
     * <p>
     * The name of a project. Using this parameter indicates to return only those jobs that are associated with the
     * specified project.
     * </p>
     */
    private String projectName;

    /**
     * <p>
     * The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     * dataset.
     * </p>
     * 
     * @param datasetName
     *        The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     *        dataset.
     */

    public void setDatasetName(String datasetName) {
        this.datasetName = datasetName;
    }

    /**
     * <p>
     * The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     * dataset.
     * </p>
     * 
     * @return The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     *         dataset.
     */

    public String getDatasetName() {
        return this.datasetName;
    }

    /**
     * <p>
     * The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     * dataset.
     * </p>
     * 
     * @param datasetName
     *        The name of a dataset. Using this parameter indicates to return only those jobs that act on the specified
     *        dataset.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public ListJobsRequest withDatasetName(String datasetName) {
        setDatasetName(datasetName);
        return this;
    }

    /**
     * <p>
     * The maximum number of results to return in this request.
     * </p>
     * 
     * @param maxResults
     *        The maximum number of results to return in this request.
     */

    public void setMaxResults(Integer maxResults) {
        this.maxResults = maxResults;
    }

    /**
     * <p>
     * The maximum number of results to return in this request.
     * </p>
     * 
     * @return The maximum number of results to return in this request.
     */

    public Integer getMaxResults() {
        return this.maxResults;
    }

    /**
     * <p>
     * The maximum number of results to return in this request.
     * </p>
     * 
     * @param maxResults
     *        The maximum number of results to return in this request.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public ListJobsRequest withMaxResults(Integer maxResults) {
        setMaxResults(maxResults);
        return this;
    }

    /**
     * <p>
     * A token generated by DataBrew that specifies where to continue pagination if a previous request was truncated. To
     * get the next set of pages, pass in the NextToken value from the response object of the previous page call.
     * </p>
     * 
     * @param nextToken
     *        A token generated by DataBrew that specifies where to continue pagination if a previous request was
     *        truncated. To get the next set of pages, pass in the NextToken value from the response object of the
     *        previous page call.
     */

    public void setNextToken(String nextToken) {
        this.nextToken = nextToken;
    }

    /**
     * <p>
     * A token generated by DataBrew that specifies where to continue pagination if a previous request was truncated. To
     * get the next set of pages, pass in the NextToken value from the response object of the previous page call.
     * </p>
     * 
     * @return A token generated by DataBrew that specifies where to continue pagination if a previous request was
     *         truncated. To get the next set of pages, pass in the NextToken value from the response object of the
     *         previous page call.
     */

    public String getNextToken() {
        return this.nextToken;
    }

    /**
     * <p>
     * A token generated by DataBrew that specifies where to continue pagination if a previous request was truncated. To
     * get the next set of pages, pass in the NextToken value from the response object of the previous page call.
     * </p>
     * 
     * @param nextToken
     *        A token generated by DataBrew that specifies where to continue pagination if a previous request was
     *        truncated. To get the next set of pages, pass in the NextToken value from the response object of the
     *        previous page call.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public ListJobsRequest withNextToken(String nextToken) {
        setNextToken(nextToken);
        return this;
    }

    /**
     * <p>
     * The name of a project. Using this parameter indicates to return only those jobs that are associated with the
     * specified project.
     * </p>
     * 
     * @param projectName
     *        The name of a project. Using this parameter indicates to return only those jobs that are associated with
     *        the specified project.
     */

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    /**
     * <p>
     * The name of a project. Using this parameter indicates to return only those jobs that are associated with the
     * specified project.
     * </p>
     * 
     * @return The name of a project. Using this parameter indicates to return only those jobs that are associated with
     *         the specified project.
     */

    public String getProjectName() {
        return this.projectName;
    }

    /**
     * <p>
     * The name of a project. Using this parameter indicates to return only those jobs that are associated with the
     * specified project.
     * </p>
     * 
     * @param projectName
     *        The name of a project. Using this parameter indicates to return only those jobs that are associated with
     *        the specified project.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public ListJobsRequest withProjectName(String projectName) {
        setProjectName(projectName);
        return this;
    }

    /**
     * Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be
     * redacted from this string using a placeholder value.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDatasetName() != null)
            sb.append("DatasetName: ").append(getDatasetName()).append(",");
        if (getMaxResults() != null)
            sb.append("MaxResults: ").append(getMaxResults()).append(",");
        if (getNextToken() != null)
            sb.append("NextToken: ").append(getNextToken()).append(",");
        if (getProjectName() != null)
            sb.append("ProjectName: ").append(getProjectName());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ListJobsRequest == false)
            return false;
        ListJobsRequest other = (ListJobsRequest) obj;
        if (other.getDatasetName() == null ^ this.getDatasetName() == null)
            return false;
        if (other.getDatasetName() != null && other.getDatasetName().equals(this.getDatasetName()) == false)
            return false;
        if (other.getMaxResults() == null ^ this.getMaxResults() == null)
            return false;
        if (other.getMaxResults() != null && other.getMaxResults().equals(this.getMaxResults()) == false)
            return false;
        if (other.getNextToken() == null ^ this.getNextToken() == null)
            return false;
        if (other.getNextToken() != null && other.getNextToken().equals(this.getNextToken()) == false)
            return false;
        if (other.getProjectName() == null ^ this.getProjectName() == null)
            return false;
        if (other.getProjectName() != null && other.getProjectName().equals(this.getProjectName()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getDatasetName() == null) ? 0 : getDatasetName().hashCode());
        hashCode = prime * hashCode + ((getMaxResults() == null) ? 0 : getMaxResults().hashCode());
        hashCode = prime * hashCode + ((getNextToken() == null) ? 0 : getNextToken().hashCode());
        hashCode = prime * hashCode + ((getProjectName() == null) ? 0 : getProjectName().hashCode());
        return hashCode;
    }

    @Override
    public ListJobsRequest clone() {
        return (ListJobsRequest) super.clone();
    }

}
